//+------------------------------------------------------------------+
//|                                                DrawNewsLines.mq5 |
//|                                  Copyright 2025, MetaQuotes Ltd. |
//|                                             https://www.mql5.com |
//+------------------------------------------------------------------+
#property copyright "Copyright 2025, MetaQuotes Ltd."
#property link      "https://www.mql5.com"
#property version   "1.00"



#include <CalendarHistory.mqh>
CArrayCalendarEntry entries;
#define FILE_NAME "CalendarHistory.bin"


void OnInit() {
   CCalendarHistory cal;
   
   cal.SaveCalendarValuesToFile(FILE_NAME);
   
   // Check if file exists
   if (!FileIsExist("CalendarHistory.bin", FILE_COMMON)) {
      Print("Error: CalendarHistory.bin does not exist in common folder!");
      return;
   }

   // Load entries from November 1, 2024 onward
   datetime timeFrom = D'2024.11.01'; // Start of November 2024
   if (!cal.LoadCalendarEntriesFromFile("CalendarHistory.bin", entries, timeFrom, 0,true)) {
      Print("Error: Failed to load CalendarHistory.bin");
      return;
   }

   // Print number of loaded entries
   Print("Loaded ", entries.Total(), " entries before filtering");

   // Apply filter for USD high-importance events
   entries.Filter("USD", CALENDAR_IMPORTANCE_HIGH);
   Print("After filtering (USD, HIGH): ", entries.Total(), " entries");
   
   // Test manual line creation
   
   datetime test_time = StringToTime("2024.11.01 15:30");
   string test_name = "[TEST] Manual Line";
   if (ObjectCreate(0, test_name, OBJ_VLINE, 0, test_time, 0)) {
      ObjectSetInteger(0, test_name, OBJPROP_STYLE, STYLE_SOLID);
      ObjectSetInteger(0, test_name, OBJPROP_WIDTH, 3);
      ObjectSetInteger(0, test_name, OBJPROP_COLOR, clrBlue);
      datetime actual_test_time = (datetime)ObjectGetTimeByValue(0, test_name, 0);
      Print("Test line created at: ", TimeToString(test_time), 
            ", Actual position: ", TimeToString(actual_test_time));
   } else {
      Print("Failed to create test line, Error: ", GetLastError());
   }
   
   
   // Draw lines
   for (int i = 0; i < entries.Total(); i++) {
      CCalendarEntry* entry = entries.At(i);
      if (entry == NULL) {
         Print("Error: Null entry at index ", i);
         continue;
      }
      Print("Drawing line for: ", entry.ToString(), " at time: ", TimeToString(entry.value_time));
      if (!entry.DrawLine()) {
         Print("Failed to create line for: ", entry.ToString());
      }
   }

   // Force chart redraw coz why not 
   ChartRedraw(0);
   Print("Finished attempting to draw ", entries.Total(), " news lines...");
}

